Клиентское приложение
=============================================

Клиентское приложение мессенджера. Подключается к серверу и обменивается с ними сообщениями. Имеет графический интерфейс. 

**Запуск клиента**

Запуск клиента выполняется из корневой директории путем вызова модуля ``client.py`` из командной строки с параметрами: 

1. -a / --host - Адрес сервера.
2. -b / --port - Порт сервера.
3. -u / --user - Логин пользователя.
4. -p / --password - Пароль пользователя.

*В данном режиме не поддерживается ввод команд.*

Примеры использования:

``python client.py -a 127.0.0.1 -b 8080``

*Запуск клиента для подключения к серверу по адресу 127.0.0.1:8080*

``python client.py -a 127.0.0.1 -b 8080 -u login1 -p password1``

*Запуск клиента для подключения к серверу по адресу 127.0.0.1:8080 с учетными данными login1/password1*



client.py
~~~~~~~~~

Запускаемый модуль,содержит парсер аргументов командной строки и функционал инициализации приложения.


